<?php

class Xoogu_WPAA_Carousel
{
	//@var array $aEnabledLocales MarketPlaces the carousel widget works for
	protected $aEnabledLocales = array(
		"US" => true,
        "GB" => true,
        "CA" => true,
        "DE" => true,
        "FR" => true,
        "JP" => true
		//ES and IT don't support SearchAndAdd or ASINList
		//CN and IN don't support SearchAndAdd but do support ASINList. For the moment we will just disable them completely.
		//Can only sign up to India affiliate scheme if a resident of India
        //"IT" => true,
        //"ES" => true,
		//"CN" => true,
		//"IN" => true
    );
	
	//@var array $aOptions Options for the plugin, saved to / pulled from the db
	protected $aOptions;
	
	public function __construct()
	{
		//Don't do anything if WPAA isn't available
		if (empty($GLOBALS['wpaa'])) {
			return;
		}
		$this->aOptions = get_option('xoogu_wpaa_carousel');
		add_shortcode('amazon_carousel', array(&$this,'amazonCarouselHandler'));
		add_action('wp_enqueue_scripts', array($this, 'enqueuejscss'));
	}
	
	public function enqueuejscss()
	{
		if (is_admin()) {
			return;
		}
		wp_enqueue_style( 'xoogu-wpaa-carousel', plugins_url( 'amazon-carousel.css' , __FILE__ ), null, $this->aOptions['version']);
	}
	
	/**
	 * Creates a div with the shortcode attributes as data- attrs, for the amazon js carousel to handle
	 * If the widget type is not supported by the js, then it will call the default WPAA handler to generate the flash js instead
	 * @param array $attrs The shortcode attributes
	 * @param string $content The content of the shortcode (should be empty)
	 * @param string $shortcode The shortcode tag (amazon_carousel)
	 * @return string The html to replace the shortcode with
	 */
	public function amazonCarouselHandler($attrs, $content, $shortcode)
	{
		//If there's some setting we don't support, let WPAA add the flash widget
		if (!in_array($attrs['widget_type'], array('SearchAndAdd','ASINList'))) {
			static $scHandler;
			if (!$scHandler) {
				$scHandler = new WPAA_ShortCodeHandler($GLOBALS['wpaa']->getModule(WPAA::MODULE_COMPLIANCE)->getCompliantShortCodeMappings());
			}
			return $scHandler->amazonCarouselHandler($attrs, $content, $shortcode);
		}
		
		if (!empty($this->aOptions['geoLookup'])) {
			$upload_dir = wp_upload_dir();
			wp_enqueue_script( 'xoogu-wpaa-carousel', $upload_dir['baseurl'].'/amazon-carousel.js', null, $this->aOptions['version'], true );
		} else {
			wp_enqueue_script( 'xoogu-wpaa-carousel', plugins_url( 'amazon-carousel.js' , __FILE__ ), null, $this->aOptions['version'], true );
		}
		
		
		//We'll merge the supplied attributes with the defaults supplied by WPAA
		$attrs = shortcode_atts( AmazonWidget_Carousel::getDefaultShortCodeOptions(), $attrs );
		
		//marketPlace specified by user in shortcode attributes
		if (!empty($attrs['market_place'])) {
			 $sMarketPlace = $attrs['market_place'];
			 //If the marketPlace chosen is not supported, use GeoIP lookup
			 if (empty($this->aEnabledLocales[$sMarketPlace])) {
				$sMarketPlace = $this->getGeoMarketPlace();
			 }
		//Lookup marketplace from browser's lang in js (e.g. if page will be cached)
		} elseif ($this->aOptions['geoLookup'] == 'js_lang') {
			$sMarketPlace = '';
		//Lookup marketplace using geoIP
		} else {
			$sMarketPlace = $this->getGeoMarketPlace();
		}
		
		$str = '<div class="amazon-carousel" data-widgetType="'.$attrs['widget_type'].'" data-title="'.$attrs['title'].'" data-marketPlace="'.$sMarketPlace.'" data-shuffleProducts="'.$attrs['shuffle_products'].'" data-tag="'.($sMarketPlace ? $this->getAssociateId($sMarketPlace) : '').'" ';
		if ($attrs['widget_type'] == 'SearchAndAdd') {
			$str.= 'data-keywords="'.$attrs['keywords'].'" data-searchIndex="'.$attrs['search_index'].'" ';
		} elseif ($attrs['widget_type'] == 'ASINList') {
			$str.= 'data-ASIN="'.$attrs['asin'].'" ';
		}
		$str.= '></div>';
		return $str;
	}
	
	
	/**
	 *Looks up the marketplace based on the user's IP address
	 *@return string The 2 digit country code of the marketplace
	 */
	protected function getGeoMarketPlace()
	{
		$sMarketPlace = AmazonWidget_Carousel::getGeoMarket();
		if (empty($this->aEnabledLocales[$sMarketPlace])) {
			//If marketplace is not supported then get the default marketplace
			$sMarketPlace = AmazonWidget_Carousel::getDefaultMarket();
			if (empty($this->aEnabledLocales[$sMarketPlace])) {
				//If default marketplace is not supported then use US
				$sMarketPlace = 'US';
			}
		}
		return $sMarketPlace;
	}
	
	
	/**
	 * Slightly modified from wpaa/AmazonWidget/Abstract.php
     * get AssociateId based on MarketPlace
     * @param string $sMarketPlace The Marketplace to get the affiliate id for
     * @global WPAA $wpaa
     * @return string
     */
    protected function getAssociateId($sMarketPlace) {
        global $wpaa;
        global $post;
        $author_id = null;
        if( !is_null( $post ) && isset( $post->post_author ) ) {
            $author_id = $post->post_author;
        }
        switch( $sMarketPlace ) {
            case "GB":
                return $wpaa->getAssociateId( "UK", $author_id );
                break;
            case "US":
            case "CA":
            case "DE":
            case "ES":
            case "FR":
            case "JP":
            case "IT":
            case "CN":
                return $wpaa->getAssociateId( $sMarketPlace, $author_id );
                break;
            default:
                return $wpaa->getAssociateId( null, $author_id );
                break;
        }
    }
}
