<?php

class Xoogu_WPAA_Carousel_Admin extends Xoogu_WPAA_Carousel
{
	public function __construct()
	{
		parent::__construct();
		add_action('toplevel_page_wordpress-advertising-associate-config', array($this, 'adminOptions'), 11);
		add_action('admin_head-toplevel_page_wordpress-advertising-associate-config', array($this, 'adminProcessPost'), 9);
		$sMainPluginFile = dirname(__FILE__).'/xoogu-wpaa-carousel.php';
        register_activation_hook( $sMainPluginFile, array($this, 'activate'));
        register_uninstall_hook( $sMainPluginFile, array('Xoogu_CurrencyConversion_Admin', 'uninstall'));
		load_plugin_textdomain('xoogu-wpaa-carousel', false, dirname(__FILE__).'/lang/');
	}
	
	
	/**
	 *Saves the initial settings in the db if no settings exist
	 */
	public function activate()
	{
		if (empty($this->aOptions)) {
			$this->aOptions = array('geoLookup' => '', 'version' => '2015-08-11');
			update_option('xoogu_wpaa_carousel', $this->aOptions);
		}
	}
	
	
	/**
	 *Removes the db entry on uninstall
	 */
	public static function uninstall()
	{
		delete_option('xoogu_wpaa_carousel');
		//Delete js files
	}
	
	public function adminProcessPost()
	{
		if (empty($_POST)) {
			return;
		}
		$aAvailableOpts = array('js_lang' => true);
		if (!empty($_POST['xoogu-wpaa-carousel']['geoLookup'])) {
			//We only need to save the js geo lookup version of the js if we haven't already saved it, or if it's enabled and the default country has been changed
			if (!empty($aAvailableOpts[$_POST['xoogu-wpaa-carousel']['geoLookup']]) && (empty($this->aOptions['geoLookup']) || $_POST['xoogu-wpaa-carousel-original-locale'] != $_POST['Locale'])) {
				
				//Save the js
				//Get the affiliate tags and fix the UK/GB weirdness
				$aAffTags = $GLOBALS['wpaa']->getAssociateTags();
				$aAffTags['GB'] = $aAffTags['UK'];
				unset($aAffTags['UK']);
				//Get the default MarketPlace and fix the UK/GB weirdness
				$sDefaultMarketPlace = $GLOBALS['wpaa']->getLocale();
				switch ($sDefaultMarketPlace) {
					case 'UK' :
						$sDefaultMarketPlace = 'GB';
						break;
					//ES and IT aren't supported so can't be used as default locale
					case 'ES' :
					case 'IT' :
					//CN and IN don't support SearchAndAdd - for moment we disable them completely
					case 'CN' :
					case 'IN' :
						$sDefaultMarketPlace = 'US';
						break;
				}
				//Read js file
				if ( file_exists(dirname(__FILE__).'/amazon-carousel.js') && ($sJS = file_get_contents(dirname(__FILE__).'/amazon-carousel.js')) ) {
					//Replace line with aff tags
					$sJS = str_replace(array('{addCarousels()', 'var sDefaultMarketPlace = \'US\''), array('{addCarousels('.json_encode($aAffTags).')', "var sDefaultMarketPlace = '$sDefaultMarketPlace'"), $sJS);
					//Write file to uploads / files dir
					$upload_dir = wp_upload_dir();
					file_put_contents($upload_dir['basedir'].'/amazon-carousel.js', $sJS);
				
					//Update the DB
					$this->aOptions['geoLookup'] = $_POST['xoogu-wpaa-carousel']['geoLookup'];
					update_option('xoogu_wpaa_carousel', $this->aOptions);
				} else {
					echo '<div class="error">'.__('Xoogu WPAA Carousel settings not updated - couldn\'t find the amazon-carousel.js file','xoogu-wpaa-carousel').'</div>';
				}
			}
		//If we previously had js geoLookup set but have unset it, update the db to that effect
		} elseif (empty($_POST['xoogu-wpaa-carousel']['geoLookup']) && !empty($this->aOptions['geoLookup'])) {
			$this->aOptions['geoLookup'] = '';
			update_option('xoogu_wpaa_carousel', $this->aOptions);
			//Delete the old js file
			$upload_dir = wp_upload_dir();
			if (file_exists($upload_dir['basedir'].'/amazon-carousel.js')) {
				unlink($upload_dir['basedir'].'/amazon-carousel.js');
			}
		}
	}
	
	
	/**
	 *Prints the admin settings on the main WPAA settings screen
	 *Note - uses js to insert the settings within the WPAA form
	 */
	public function adminOptions()
	{
		
		$content = '<div class="admin_config_box">';
		$content .= '<table border="0" class="admin_table">';
		$content .= '<tr><td><strong>' . __('GeoLookup Method:','xoogu-wpaa-carousel') . '</strong></td><td><ul><li><input type="radio" value="" id="xoogu-wpaa-carousel-geoLookup-default" name="xoogu-wpaa-carousel[geoLookup]" '.(empty($this->aOptions['geoLookup']) ? 'checked="checked" ' : '').'/><label for="xoogu-wpaa-carousel-geoLookup-default">'.__('Use WPAA setting','xoogu-wpaa-carousel').'</label></li><li><input type="radio" value="js_lang" id="xoogu-wpaa-carousel-geoLookup-js_lang" name="xoogu-wpaa-carousel[geoLookup]" '.($this->aOptions['geoLookup'] == 'js_lang' ? 'checked="checked" ' : '').'/><label for="xoogu-wpaa-carousel-geoLookup-js_lang">'.__('Use js lookup of browser language','xoogu-wpaa-carousel').'</label></li></ul></td></tr>';
		$content .= '</table>';
		$content .= '<div class="alignright"><input class="button-primary" type="submit" name="submit" value="' . __('Update Settings','wpaa') . ' &raquo;" /></div>';
		$content .= '<div class="clear"></div>';
		$content .= "<p>" . sprintf(__('If you use a static page caching plugin (such as %1 or %2), then it is recommended that you choose the js lookup option. This will attempt to determine the user\'s location based on the preferred language set in their browser. If you do not use a static page cache, then it is recommended that you use the WPAA setting.','xoogu-wpaa-carousel'), '<abbr title="'.__('W3 Total Cache','xoogu-wpaa-carousel').'">'.__('W3TC','xoogu-wpaa-carousel').'</abbr>', '<abbr title="'.__('WordPress Super Cache','xoogu-wpaa-carousel').'">'.__('WPSC','xoogu-wpaa-carousel').'</abbr>') . "</p>";
		//Make it easy to tell if the Default MarketPlace has been changed
		$content .= '<input type="hidden" value="'.$GLOBALS['wpaa']->getLocale().'" name="xoogu-wpaa-carousel-original-locale" />';
		$content .= '</div>';
		//echo '<div id="absolutely-hacky-way-of-injecting-html"><!--';
		$GLOBALS['wpaa']->postbox("amazon_associate_xoogu_carousel", __("Xoogu WPAA Carousel Settings",'xoogu-wpaa-carousel'), $content);
		//echo '--></div>';
		?><script type="text/javascript">(function(){document.getElementById('amazon_associate_content_viewer_settings').parentNode.appendChild(document.getElementById('amazon_associate_xoogu_carousel'));})();</script><?php
	}
}
